import os
import json

configPath = os.getenv("CONFIG_PATH", "config/config.json")


class Config:
    def __init__(self):
        try:
            with open(configPath, "r") as fileObj:
                self.config = json.load(fileObj.read())
        except FileNotFoundError:
            print("Warning: no config file found")
            self.config = {}

    def get(self, key, default):
        try:
            return self.config[key]
        except KeyError:
            return default


config = Config()



import setuptools

setuptools.setup(
    name="config_bat",
    version="0.1.0",
    author="Ninh Chu",
    author_email="chulucninh09@gmail.com",
    description="A small example package",
    packages=setuptools.find_packages(),
    classifiers=[
        "Programming Language :: Python :: 3",
        "License :: OSI Approved :: MIT License",
        "Operating System :: OS Independent",
    ],
)
